@@ -50,6 +50,18 @@ module Hasql.Decoders
     jsonBytes,
     jsonb,
     jsonbBytes,
+    int4range,
+    int8range,
+    numrange,
+    tsrange,
+    tstzrange,
+    daterange,
+    int4multirange,
+    int8multirange,
+    nummultirange,
+    tsmultirange,
+    tstzmultirange,
+    datemultirange,
     array,
     listArray,
     vectorArray,
