@@ -41,6 +41,18 @@ module Hasql.Encoders
     jsonb,
     jsonbBytes,
     jsonbLazyBytes,
+    int4range,
+    int8range,
+    numrange,
+    tsrange,
+    tstzrange,
+    daterange,
+    int4multirange,
+    int8multirange,
+    nummultirange,
+    tsmultirange,
+    tstzmultirange,
+    datemultirange,
     name,
     oid,
     enum,
